==> julia-git-optimization-src-3.28.0-1-any.pkg.tar.zst: usr/share/julia/arch-site/Optimization/docs/pages.jl <==
pages = ["index.md",
    "getting_started.md",
    "Tutorials" => [
        "tutorials/minibatch.md",
        "tutorials/symbolic.md",
        "tutorials/constraints.md",
        "tutorials/linearandinteger.md"
    ],
    "Examples" => [
        "examples/rosenbrock.md"
    ],
    "Basics" => [
        "API/optimization_problem.md",
        "API/optimization_function.md",
        "API/ad.md",
        "API/solve.md",
        "API/optimization_solution.md",
        "API/optimization_state.md",
        "API/optimization_stats.md",
        "API/modelingtoolkit.md",
        "API/FAQ.md"
    ],
    "Optimizer Packages" => [
        "BlackBoxOptim.jl" => "optimization_packages/blackboxoptim.md",
        "CMAEvolutionStrategy.jl" => "optimization_packages/cmaevolutionstrategy.md",
        "Evolutionary.jl" => "optimization_packages/evolutionary.md",
        "GCMAES.jl" => "optimization_packages/gcmaes.md",
        "Manopt.jl" => "optimization_packages/manopt.md",
        "MathOptInterface.jl" => "optimization_packages/mathoptinterface.md",
        "Metaheuristics.jl" => "optimization_packages/metaheuristics.md",
        "MultistartOptimization.jl" => "optimization_packages/multistartoptimization.md",
        "NLopt.jl" => "optimization_packages/nlopt.md",
        "NOMAD.jl" => "optimization_packages/nomad.md",
        "Optim.jl" => "optimization_packages/optim.md",
        "Optimisers.jl" => "optimization_packages/optimisers.md",
        "PRIMA.jl" => "optimization_packages/prima.md",
        "Polyalgorithms.jl" => "optimization_packages/polyopt.md",
        "QuadDIRECT.jl" => "optimization_packages/quaddirect.md",
        "SpeedMapping.jl" => "optimization_packages/speedmapping.md",
        "NLPModels.jl" => "optimization_packages/nlpmodels.md"
    ]
]

==> julia-git-optimization-src-4.0.5-1-any.pkg.tar.zst: usr/share/julia/arch-site/Optimization/docs/pages.jl <==
pages = ["index.md",
    "getting_started.md",
    "Tutorials" => [
        "tutorials/certification.md",
        "tutorials/constraints.md",
        "tutorials/ensemble.md",
        "tutorials/linearandinteger.md",
        "tutorials/minibatch.md",
        "tutorials/remakecomposition.md",
        "tutorials/symbolic.md"
    ],
    "Examples" => [
        "examples/rosenbrock.md"
    ],
    "Basics" => [
        "API/optimization_problem.md",
        "API/optimization_function.md",
        "API/ad.md",
        "API/solve.md",
        "API/optimization_solution.md",
        "API/optimization_state.md",
        "API/optimization_stats.md",
        "API/modelingtoolkit.md",
        "API/FAQ.md"
    ],
    "Optimizer Packages" => [
        "BlackBoxOptim.jl" => "optimization_packages/blackboxoptim.md",
        "CMAEvolutionStrategy.jl" => "optimization_packages/cmaevolutionstrategy.md",
        "Evolutionary.jl" => "optimization_packages/evolutionary.md",
        "GCMAES.jl" => "optimization_packages/gcmaes.md",
        "Manopt.jl" => "optimization_packages/manopt.md",
        "MathOptInterface.jl" => "optimization_packages/mathoptinterface.md",
        "Metaheuristics.jl" => "optimization_packages/metaheuristics.md",
        "MultistartOptimization.jl" => "optimization_packages/multistartoptimization.md",
        "NLopt.jl" => "optimization_packages/nlopt.md",
        "NLPModels.jl" => "optimization_packages/nlpmodels.md",
        "NOMAD.jl" => "optimization_packages/nomad.md",
        "Optim.jl" => "optimization_packages/optim.md",
        "Optimisers.jl" => "optimization_packages/optimisers.md",
        "Optimization.jl" => "optimization_packages/optimization.md",
        "Polyalgorithms.jl" => "optimization_packages/polyopt.md",
        "PRIMA.jl" => "optimization_packages/prima.md",
        "QuadDIRECT.jl" => "optimization_packages/quaddirect.md",
        "SpeedMapping.jl" => "optimization_packages/speedmapping.md"
    ]
]
